@@ -17,10 +17,10 @@ use strict;
 use warnings;
 
 package MongoDB;
-# ABSTRACT: Official MongoDB Driver for Perl
+# ABSTRACT: Official MongoDB Driver for Perl (EOL)
 
 use version;
-our $VERSION = 'v2.2.1';
+our $VERSION = 'v2.2.2';
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -79,18 +79,28 @@ sub connect {
 
 =head1 NAME
 
-MongoDB - Official MongoDB Driver for Perl
+MongoDB - Official MongoDB Driver for Perl (EOL)
 
 =head1 VERSION
 
-version v2.2.1
+version v2.2.2
 
 =head1 END OF LIFE NOTICE
 
-Version v2.2.0 is the final feature release of the MongoDB Perl driver.
-The driver is now in a 12-month "sunset" period and will receive security
-patches and critical bug fixes only.  The Perl driver will be end-of-life
-and unsupported on August 13, 2020.
+Version v2.2.0 was the final feature release of the MongoDB Perl driver and
+version v2.2.2 is the final patch release.
+
+B<As of August 13, 2020, the MongoDB Perl driver and related libraries have
+reached end of life and are no longer supported by MongoDB.> See the
+L<August 2019 deprecation
+notice|https://www.mongodb.com/blog/post/the-mongodb-perl-driver-is-being-deprecated>
+for rationale.
+
+If members of the community wish to continue development, they are welcome
+to fork the code under the terms of the Apache 2 license and release it
+under a new namespace.  Specifications and test files for MongoDB drivers
+and libraries are published in an open repository:
+L<mongodb/specifications|https://github.com/mongodb/specifications/tree/master/source>.
 
 =head1 SYNOPSIS
 
@@ -205,6 +215,14 @@ For example, if the set name is C<"setA">:
 
 =end Pod::Coverage
 
+=head1 SUPPORTED MONGODB VERSIONS
+
+The driver has been tested against MongoDB versions 2.6 through 4.2.  All
+features of these versions are supported, except for field-level
+encryption.  The driver may work with future versions of MongoDB, but will
+not include support for new MongoDB features and should be B<thoroughly
+tested> within applications before deployment.
+
 =head1 SEMANTIC VERSIONING SCHEME
 
 Starting with MongoDB C<v1.0.0>, the driver reverts to the more familiar
@@ -248,21 +266,6 @@ Per L<threads> documentation, use of Perl threads is discouraged by the
 maintainers of Perl and the MongoDB Perl driver does not test or provide support
 for use with threads.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker at L<https://jira.mongodb.org/browse/PERL>.  You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for public review and contribution under the terms of the license.
-L<https://github.com/mongodb/mongo-perl-driver>
-
-  git clone https://github.com/mongodb/mongo-perl-driver.git
-
 =head1 AUTHORS
 
 =over 4
@@ -579,7 +582,7 @@ Zhihong Zhang <zzh_621@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by MongoDB, Inc.
+This software is Copyright (c) 2020 by MongoDB, Inc.
 
 This is free software, licensed under:
 
